@@ -48,11 +48,6 @@ struct color {
    {
       return !(*this==clr);
    }
-   color &operator=(const color &clr)
-   {
-      r=clr.r; g=clr.g; b=clr.b;
-      return *this;
-   }
 };
 
 typedef std::vector<color> colorvect;
@@ -73,11 +68,6 @@ struct font {
    {
       return !(*this==f);
    }
-   font &operator=(const font &f)
-   {
-      family=f.family; name=f.name; pitch=f.pitch; charset=f.charset;
-      return *this;
-   }
 };
 
 typedef std::map<int, font> fontmap;
@@ -116,18 +106,6 @@ struct formatting_options
    {
       return !(*this==opt);
    }
-   formatting_options &operator=(const formatting_options &opt)
-   {
-      chpBold=opt.chpBold; chpItalic=opt.chpItalic;
-      chpUnderline=opt.chpUnderline; chpVAlign=opt.chpVAlign;
-      chpFontSize=opt.chpFontSize;
-      chpFColor=opt.chpFColor; chpBColor=opt.chpBColor;
-      chpHighlight=opt.chpHighlight; chpFont=opt.chpFont;
-      papLeft=opt.papLeft; papRight=opt.papRight;
-      papFirst=opt.papFirst; papBefore=opt.papBefore; papAfter=opt.papAfter;
-      papAlign=opt.papAlign; papInTbl=opt.papInTbl;
-      return *this;
-   }
    std::string get_par_str() const;
 };
 
