@@ -56,7 +56,6 @@ Document* Document::s_self = nullptr;
 Document::Document() : QObject(), m_coll(nullptr), m_isModified(false),
     m_loadAllImages(false), m_validFile(false), m_importer(nullptr), m_cancelImageWriting(true),
     m_fileFormat(Import::TellicoImporter::Unknown), m_loadImagesTimer(this) {
-  m_allImagesOnDisk = Config::imageLocation() != Config::ImagesInFile;
   m_loadImagesTimer.setSingleShot(true);
   m_loadImagesTimer.setInterval(500);
   connect(&m_loadImagesTimer, &QTimer::timeout, this, &Document::slotLoadAllImages);
@@ -77,6 +76,12 @@ void Document::setURL(const QUrl& url_) {
   if(m_url.fileName() != TC_I18N1(Tellico::untitledFilename)) {
     ImageFactory::setLocalDirectory(m_url);
     EntryComparison::setDocumentUrl(m_url);
+  } else {
+    // important to set the local directory so new temporary images are not saved incorrectly
+    // rather than passing the untitle file name, we want an empty url
+    // per ImageFactory::cacheDir() logic
+    QUrl u;
+    ImageFactory::setLocalDirectory(u);
   }
 }
 
@@ -155,7 +160,6 @@ bool Document::openDocument(const QUrl& url_) {
   // format is only known AFTER collection() is called
 
   m_fileFormat = m_importer->format();
-  m_allImagesOnDisk = !m_importer->hasImages();
   if(!m_importer->hasImages() || m_fileFormat != Import::TellicoImporter::Zip) {
     m_loadAllImages = true;
   }
@@ -348,7 +352,7 @@ Tellico::Data::MergePair Document::mergeCollection(Tellico::Data::CollPtr coll1_
   coll1_->blockSignals(true);
   Data::FieldList fields = coll2_->fields();
   foreach(FieldPtr field, fields) {
-    bool collChange = coll1_->mergeField(field);
+    const bool collChange = coll1_->mergeField(field);
     if(collChange && structuralChange_) *structuralChange_ = true;
   }
 
@@ -376,7 +380,7 @@ Tellico::Data::MergePair Document::mergeCollection(Tellico::Data::CollPtr coll1_
       for(int i = 0; i < currTotal; ++i) {
         // since we're sorted by title, track the index of the previous match and start comparison there
         currEntry = currEntries.at((i+lastMatchId) % currTotal);
-        const int match = coll1_->sameEntry(currEntry, newEntry);
+        const auto match = coll1_->sameEntry(currEntry, newEntry);
         if(match >= EntryComparison::ENTRY_PERFECT_MATCH) {
           matchEntry = currEntry;
           lastMatchId = (i+lastMatchId) % currTotal;
@@ -627,7 +631,7 @@ void Document::writeAllImages(int cacheDir_, const QUrl& localDir_) {
       }
       // careful here, if we're writing to LocalDir, need to read from the old LocalDir and write to new
       bool success;
-      if(cacheDir == ImageFactory::LocalDir) {
+      if(imgDir) {
         success = ImageFactory::writeCachedImage(id, imgDir.data());
       } else {
         success = ImageFactory::writeCachedImage(id, cacheDir);
