@@ -25,18 +25,16 @@
 #include "entryview.h"
 #include "entry.h"
 #include "field.h"
+#include "collection.h"
+#include "document.h"
 #include "translators/xslthandler.h"
 #include "translators/tellicoxmlexporter.h"
-#include "collection.h"
 #include "images/imagefactory.h"
 #include "images/imageinfo.h"
-#include "tellico_kernel.h"
 #include "utils/tellico_utils.h"
 #include "utils/datafileregistry.h"
-#include "config/tellico_config.h"
-#include "gui/drophandler.h"
 #include "utils/cursorsaver.h"
-#include "document.h"
+#include "config/tellico_config.h"
 #include "tellico_debug.h"
 
 #include <KMessageBox>
@@ -53,6 +51,7 @@
 #include <QApplication>
 #include <QDesktopServices>
 #include <QMenu>
+#include <QContextMenuEvent>
 
 #ifdef USE_KHTML
 #include <dom/dom_element.h>
@@ -154,28 +153,24 @@ QWebEnginePage* EntryViewPage::createWindow(QWebEnginePage::WebWindowType type_)
 }
 
 void EntryViewPage::openExternalLink(const QUrl& url_) {
-  const QUrl finalUrl = Kernel::self()->URL().resolved(url_);
+  const QUrl finalUrl = Data::Document::self()->URL().resolved(url_);
   QDesktopServices::openUrl(finalUrl);
 }
 
-EntryView::EntryView(QWidget* parent_) : QWebEngineView(parent_),
-    m_handler(nullptr), m_tempFile(nullptr), m_useGradientImages(true), m_checkCommonFile(true) {
+EntryView::EntryView(QWidget* parent_) : QWebEngineView(parent_)
+    , m_handler(nullptr)
+    , m_tempFile(nullptr)
+    , m_useGradientImages(true)
+    , m_checkCommonFile(true) {
   auto page = new EntryViewPage(this);
   setPage(page);
   if(m_printer.resolution() < 300) {
     m_printer.setResolution(300);
   }
 
-  connect(this, &QWebEngineView::loadFinished, this, [](bool b) {
-    if(!b) myDebug() << "EntryView - failed to load view";
-  });
   connect(page, &EntryViewPage::signalTellicoAction,
           this, &EntryView::signalTellicoAction);
 
-  setAcceptDrops(true);
-  auto drophandler = new DropHandler(this);
-  installEventFilter(drophandler);
-
   clear(); // needed for initial layout
 }
 #endif
@@ -234,7 +229,7 @@ void EntryView::showEntry(Tellico::Data::EntryPtr entry_) {
   // check if the gradient images need to be written again which might be the case if the collection is different
   // and using local directories for storage
   if(entry_ && (!m_entry || m_entry->collection() != entry_->collection()) &&
-     ImageFactory::cacheDir() == ImageFactory::LocalDir) {
+     m_useGradientImages && ImageFactory::cacheDir() == ImageFactory::LocalDir) {
     // use entry_ instead of m_entry since that's the new entry to show
     ImageFactory::createStyleImages(entry_->collection()->type());
   }
@@ -249,7 +244,7 @@ void EntryView::showEntry(Tellico::Data::EntryPtr entry_) {
   opt |= Export::ExportComplete;
   // use absolute links
   opt |= Export::ExportAbsoluteLinks;
-  // on second thought, don't auto-format everything, just clean it
+  // for Bibtex entries, don't auto-format everything, just clean it
   if(m_entry->collection()->type() == Data::Collection::Bibtex) {
     opt |= Export::ExportClean;
   }
@@ -258,7 +253,7 @@ void EntryView::showEntry(Tellico::Data::EntryPtr entry_) {
 
 //  myDebug() << dom.toString();
 #if 0
-  myWarning() << "turn me off!";
+  myWarning() << "Debug writing for EntryView";
   QFile f1(QLatin1String("/tmp/test.xml"));
   if(f1.open(QIODevice::WriteOnly)) {
     QTextStream t(&f1);
@@ -267,24 +262,31 @@ void EntryView::showEntry(Tellico::Data::EntryPtr entry_) {
   f1.close();
 #endif
 
-  const QString html = m_handler->applyStylesheet(dom.toString());
   // write out image files
+  bool useTempDir = false; // assume everything is already local
+  QStringList imagesToWrite;
   Data::FieldList fields = entry_->collection()->imageFields();
   foreach(Data::FieldPtr field, fields) {
-    QString id = entry_->field(field);
-    if(id.isEmpty()) {
+    const QString id = entry_->field(field);
+    if(id.isEmpty() || ImageFactory::imageInfo(id).linkOnly) {
       continue;
     }
-    // only write out image if it's not linked only
-    if(!ImageFactory::imageInfo(id).linkOnly) {
-      if(Data::Document::self()->allImagesOnDisk()) {
-        ImageFactory::writeCachedImage(id, ImageFactory::cacheDir());
-      } else {
-        ImageFactory::writeCachedImage(id, ImageFactory::TempDir);
-      }
-    }
+    imagesToWrite.append(id);
+    if(!useTempDir && ImageFactory::hasImageInDir(id) == false) useTempDir = true;
+  }
+  if(useTempDir) {
+    m_handler->addStringParam("imgdir", ImageFactory::tempDir().toEncoded());
+  } else {
+    m_handler->addStringParam("imgdir", ImageFactory::imageDir().toEncoded());
+  }
+  for(const auto& id : imagesToWrite) {
+    ImageFactory::writeCachedImage(id,
+                                   useTempDir ?
+                                     ImageFactory::TempDir :
+                                     ImageFactory::cacheDir());
   }
 
+  const QString html = m_handler->applyStylesheet(dom.toString());
 #if 0
   myWarning() << "EntryView::showEntry() - turn me off!";
   QFile f2(QLatin1String("/tmp/test.html"));
@@ -306,16 +308,17 @@ void EntryView::showEntry(Tellico::Data::EntryPtr entry_) {
   if(html.size() > 1200000) {
     delete m_tempFile;
     m_tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/tellicoview_XXXXXX") + QLatin1String(".html"));
-    m_tempFile->open();
+    if(m_tempFile->open()) {
     QTextStream ts(m_tempFile);
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    ts.setCodec("UTF-8");
+      ts.setCodec("UTF-8");
 #else
-    ts.setEncoding(QStringConverter::Utf8);
+      ts.setEncoding(QStringConverter::Utf8);
 #endif
-    ts << html;
-    // TODO: need to handle relative links
-    page()->load(QUrl::fromLocalFile(m_tempFile->fileName()));
+      ts << html;
+      // TODO: need to handle relative links
+      page()->load(QUrl::fromLocalFile(m_tempFile->fileName()));
+    }
   } else {
     // by setting the xslt file as the URL, any images referenced in the xslt "theme" can be found
     // by simply using a relative path in the xslt file
@@ -348,9 +351,7 @@ void EntryView::setXSLTFile(const QString& file_) {
     const QString templateDir = QStringLiteral("entry-templates/");
     m_xsltFile = DataFileRegistry::self()->locate(templateDir + file_);
     if(m_xsltFile.isEmpty()) {
-      if(!file_.isEmpty()) {
-        myWarning() << "can't locate" << file_;
-      }
+      myWarning() << "Unable to locate" << file_;
       m_xsltFile = DataFileRegistry::self()->locate(templateDir + QLatin1String("Fancy.xsl"));
       if(m_xsltFile.isEmpty()) {
         QString str = QStringLiteral("<qt>");
@@ -369,7 +370,7 @@ void EntryView::setXSLTFile(const QString& file_) {
     }
   }
 
-  const int type = m_entry ? m_entry->collection()->type() : Kernel::self()->collectionType();
+  const int type = m_entry ? m_entry->collection()->type() : Data::Document::self()->collection()->type();
 
   // we need to know if the colors changed from last time, in case
   // we need to do that ugly hack to reload the cache
@@ -413,11 +414,7 @@ void EntryView::setXSLTFile(const QString& file_) {
   m_handler->addStringParam("color2",   Config::templateHighlightedBaseColor(type).name().toLatin1());
   m_handler->addStringParam("linkcolor",Config::templateLinkColor(type).name().toLatin1());
 
-  if(Data::Document::self()->allImagesOnDisk()) {
-    m_handler->addStringParam("imgdir", ImageFactory::imageDir().toEncoded());
-  } else {
-    m_handler->addStringParam("imgdir", ImageFactory::tempDir().toEncoded());
-  }
+  // imgdir gets set when an entry is shown
   m_handler->addStringParam("datadir", QUrl::fromLocalFile(Tellico::installationDir()).toEncoded());
 
   // if we don't have to reload the images, then just show the entry and we're done
@@ -461,7 +458,7 @@ void EntryView::slotOpenURL(const QUrl& url_) {
       QString href = static_cast<DOM::Element>(node).getAttribute("href").string();
       if(!href.isEmpty()) {
         // interpret url relative to document url
-        u = Kernel::self()->URL().resolved(QUrl(href));
+        u = Data::Document::self()->URL().resolved(QUrl(href));
       }
       break;
     }
@@ -547,9 +544,7 @@ void EntryView::resetColors() {
 
   QString dir = m_handler ? QFile::decodeName(m_handler->param("imgdir")) : QString();
   if(dir.isEmpty()) {
-    dir = Data::Document::self()->allImagesOnDisk() ?
-            ImageFactory::imageDir().url() :
-            ImageFactory::tempDir().url();
+    dir = ImageFactory::imageDir().url();
   } else {
     // it's a string param, so it has quotes on both sides
     dir = dir.mid(1);
