@@ -163,7 +163,11 @@ void ArxivFetcher::slotComplete(KJob*) {
 
   if(m_total == -1) {
     QDomDocument dom;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
     if(!dom.setContent(data, true /*namespace*/)) {
+#else
+    if(!dom.setContent(data, QDomDocument::ParseOption::UseNamespaceProcessing)) {
+#endif
       myWarning() << "server did not return valid XML.";
       stop();
       return;
