@@ -55,23 +55,23 @@ public:
   CrossRefFetcher(QObject* parent);
   ~CrossRefFetcher();
 
-  virtual QString source() const Q_DECL_OVERRIDE;
-  virtual bool isSearching() const Q_DECL_OVERRIDE { return m_started; }
+  virtual QString source() const override;
+  virtual bool isSearching() const override { return m_started; }
 
-  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE { return k == DOI; }
-  virtual void stop() Q_DECL_OVERRIDE;
-  virtual Data::EntryPtr fetchEntryHook(uint uid) Q_DECL_OVERRIDE;
-  virtual Type type() const Q_DECL_OVERRIDE { return CrossRef; }
-  virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
-  virtual void readConfigHook(const KConfigGroup& config) Q_DECL_OVERRIDE;
+  virtual bool canSearch(FetchKey k) const override { return k == DOI; }
+  virtual void stop() override;
+  virtual Data::EntryPtr fetchEntryHook(uint uid) override;
+  virtual Type type() const override { return CrossRef; }
+  virtual bool canFetch(int type) const override;
+  virtual void readConfigHook(const KConfigGroup& config) override;
 
-  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const Q_DECL_OVERRIDE;
+  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const override;
 
   class ConfigWidget : public Fetch::ConfigWidget {
   public:
     explicit ConfigWidget(QWidget* parent_, const CrossRefFetcher* fetcher = nullptr);
-    virtual void saveConfigHook(KConfigGroup& config) Q_DECL_OVERRIDE;
-    virtual QString preferredName() const Q_DECL_OVERRIDE;
+    virtual void saveConfigHook(KConfigGroup& config) override;
+    virtual QString preferredName() const override;
   private:
     QLineEdit* m_userEdit;
     QLineEdit* m_passEdit;
@@ -87,8 +87,8 @@ private Q_SLOTS:
   void slotComplete(KJob* job);
 
 private:
-  virtual void search() Q_DECL_OVERRIDE;
-  virtual FetchRequest updateRequest(Data::EntryPtr entry) Q_DECL_OVERRIDE;
+  virtual void search() override;
+  virtual FetchRequest updateRequest(Data::EntryPtr entry) override;
   void initXSLTHandler();
   QUrl searchURL(FetchKey key, const QString& value) const;
 
