@@ -115,7 +115,10 @@ QString DBLPFetcher::defaultName() {
 }
 
 QString DBLPFetcher::defaultIcon() {
-  return favIcon("https://dblp.org");
+  // don't know why FavIcon job fails for this
+//  return favIcon("https://dblp.org");
+  return favIcon(QUrl(QLatin1String("https://dblp.org")),
+                 QUrl(QLatin1String("https://tellico-project.org/img/dblp-favicon.ico")));
 }
 
 Tellico::StringHash DBLPFetcher::allOptionalFields() {
