@@ -37,6 +37,11 @@
 #include <KIO/StoredTransferJob>
 #include <KJobUiDelegate>
 #include <KJobWidgets>
+#include <KLanguageName>
+#include <kguiaddons_version.h>
+#if KGUIADDONS_VERSION >= QT_VERSION_CHECK(6,0,0)
+#include <KCountryFlagEmojiIconEngine>
+#endif
 
 #include <QRegularExpression>
 #include <QLabel>
@@ -45,7 +50,6 @@
 #include <QGridLayout>
 #include <QSpinBox>
 #include <QUrlQuery>
-#include <QStandardPaths>
 
 namespace {
   static const char* FILMAFFINITY_SEARCH_URL = "https://www.filmaffinity.com";
@@ -494,12 +498,19 @@ FilmAffinityFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const FilmAffi
   label = new QLabel(i18n("Language: "), optionsWidget());
   l->addWidget(label, ++row, 0);
   m_localeCombo = new GUI::ComboBox(optionsWidget());
-  QIcon iconES(QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                      QStringLiteral("kf5/locale/countries/es/flag.png")));
-  m_localeCombo->addItem(iconES, i18nc("Country", "Spain"), int(FilmAffinityFetcher::ES));
-  QIcon iconUS(QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                      QStringLiteral("kf5/locale/countries/us/flag.png")));
-  m_localeCombo->addItem(iconUS, i18nc("Country", "USA"), int(FilmAffinityFetcher::US));
+#if KGUIADDONS_VERSION >= QT_VERSION_CHECK(6,0,0)
+  m_localeCombo->addItem(QIcon(new KCountryFlagEmojiIconEngine(QLatin1String("es"))),
+                         KLanguageName::nameForCode(QLatin1String("es")),
+                         int(FilmAffinityFetcher::ES));
+  m_localeCombo->addItem(QIcon(new KCountryFlagEmojiIconEngine(QLatin1String("us"))),
+                         KLanguageName::nameForCode(QLatin1String("en")),
+                         int(FilmAffinityFetcher::US));
+#else
+  m_localeCombo->addItem(KLanguageName::nameForCode(QLatin1String("es")),
+                         int(FilmAffinityFetcher::ES));
+  m_localeCombo->addItem(KLanguageName::nameForCode(QLatin1String("en")),
+                         int(FilmAffinityFetcher::US));
+#endif
   void (GUI::ComboBox::* activatedInt)(int) = &GUI::ComboBox::activated;
   connect(m_localeCombo, activatedInt, this, &ConfigWidget::slotSetModified);
   l->addWidget(m_localeCombo, row, 1);
