@@ -59,22 +59,22 @@ public:
 
   /**
    */
-  virtual QString source() const Q_DECL_OVERRIDE;
-  virtual QString attribution() const Q_DECL_OVERRIDE;
-  virtual bool isSearching() const Q_DECL_OVERRIDE { return m_started; }
-  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE;
-  virtual void stop() Q_DECL_OVERRIDE;
-  virtual Data::EntryPtr fetchEntryHook(uint uid) Q_DECL_OVERRIDE;
-  virtual Type type() const Q_DECL_OVERRIDE { return IGDB; }
-  virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
-  virtual void readConfigHook(const KConfigGroup& config) Q_DECL_OVERRIDE;
-  virtual void saveConfigHook(KConfigGroup& config) Q_DECL_OVERRIDE;
-  virtual void continueSearch() Q_DECL_OVERRIDE;
+  virtual QString source() const override;
+  virtual QString attribution() const override;
+  virtual bool isSearching() const override { return m_started; }
+  virtual bool canSearch(FetchKey k) const override;
+  virtual void stop() override;
+  virtual Data::EntryPtr fetchEntryHook(uint uid) override;
+  virtual Type type() const override { return IGDB; }
+  virtual bool canFetch(int type) const override;
+  virtual void readConfigHook(const KConfigGroup& config) override;
+  virtual void saveConfigHook(KConfigGroup& config) override;
+  virtual void continueSearch() override;
 
   /**
    * Returns a widget for modifying the fetcher's config.
    */
-  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const Q_DECL_OVERRIDE;
+  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const override;
 
   class ConfigWidget;
   friend class ConfigWidget;
@@ -88,8 +88,8 @@ private Q_SLOTS:
   void populateHashes();
 
 private:
-  virtual void search() Q_DECL_OVERRIDE;
-  virtual FetchRequest updateRequest(Data::EntryPtr entry) Q_DECL_OVERRIDE;
+  virtual void search() override;
+  virtual FetchRequest updateRequest(Data::EntryPtr entry) override;
   void populateEntry(Data::EntryPtr entry, const QVariantMap& resultMap);
   void markTime() const;
   void checkAccessToken();
@@ -125,8 +125,8 @@ Q_OBJECT
 
 public:
   explicit ConfigWidget(QWidget* parent_, const IGDBFetcher* fetcher = nullptr);
-  virtual void saveConfigHook(KConfigGroup&) Q_DECL_OVERRIDE;
-  virtual QString preferredName() const Q_DECL_OVERRIDE;
+  virtual void saveConfigHook(KConfigGroup&) override;
+  virtual QString preferredName() const override;
 };
 
   } // end namespace
