@@ -51,17 +51,17 @@ public:
   KinoFetcher(QObject* parent);
   virtual ~KinoFetcher();
 
-  virtual QString source() const Q_DECL_OVERRIDE;
-  virtual bool isSearching() const Q_DECL_OVERRIDE { return m_started; }
+  virtual QString source() const override;
+  virtual bool isSearching() const override { return m_started; }
   // only keyword search
-  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE { return k == Title; }
-  virtual void stop() Q_DECL_OVERRIDE;
-  virtual Data::EntryPtr fetchEntryHook(uint uid) Q_DECL_OVERRIDE;
-  virtual Type type() const Q_DECL_OVERRIDE { return Kino; }
-  virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
-  virtual void readConfigHook(const KConfigGroup& config) Q_DECL_OVERRIDE;
+  virtual bool canSearch(FetchKey k) const override { return k == Title; }
+  virtual void stop() override;
+  virtual Data::EntryPtr fetchEntryHook(uint uid) override;
+  virtual Type type() const override { return Kino; }
+  virtual bool canFetch(int type) const override;
+  virtual void readConfigHook(const KConfigGroup& config) override;
 
-  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const Q_DECL_OVERRIDE;
+  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const override;
 
   class ConfigWidget;
   friend class ConfigWidget;
@@ -74,8 +74,8 @@ private Q_SLOTS:
   void slotComplete(KJob* job);
 
 private:
-  virtual void search() Q_DECL_OVERRIDE;
-  virtual FetchRequest updateRequest(Data::EntryPtr entry) Q_DECL_OVERRIDE;
+  virtual void search() override;
+  virtual FetchRequest updateRequest(Data::EntryPtr entry) override;
   void parseEntry(Data::EntryPtr entry, const QString& str);
 
   QHash<uint, Data::EntryPtr> m_entries;
@@ -90,8 +90,8 @@ Q_OBJECT
 
 public:
   explicit ConfigWidget(QWidget* parent, const KinoFetcher* fetcher = nullptr);
-  virtual void saveConfigHook(KConfigGroup&) Q_DECL_OVERRIDE {}
-  virtual QString preferredName() const Q_DECL_OVERRIDE;
+  virtual void saveConfigHook(KConfigGroup&) override {}
+  virtual QString preferredName() const override;
 };
 
   } // end namespace
