@@ -30,15 +30,14 @@
 #include "../tellico_debug.h"
 
 #include <KLocalizedString>
-#include <KIO/Job>
+#include <KIO/StoredTransferJob>
 #include <KIO/JobUiDelegate>
 #include <KConfigGroup>
-#include <KJobWidgets/KJobWidgets>
+#include <KJobWidgets>
 
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QFile>
-#include <QTextCodec>
 #include <QUrlQuery>
 
 namespace {
@@ -148,7 +147,6 @@ void MRLookupFetcher::slotComplete(KJob* job_) {
   QFile f(QString::fromLatin1("/tmp/test-mrlookup.html"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
-    t.setCodec("UTF-8");
     t << data;
   }
   f.close();
@@ -173,7 +171,6 @@ void MRLookupFetcher::slotComplete(KJob* job_) {
   QFile f(QString::fromLatin1("/tmp/test.bibtex"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
-    t.setCodec("UTF-8");
     t << bibtexString;
   }
   f.close();
