@@ -26,6 +26,7 @@
 #include "../collections/bookcollection.h"
 #include "../collections/comicbookcollection.h"
 #include "../images/imagefactory.h"
+#include "../gui/combobox.h"
 #include "../utils/isbnvalidator.h"
 #include "../utils/guiproxy.h"
 #include "../utils/mapvalue.h"
@@ -56,7 +57,7 @@ using namespace Tellico;
 using Tellico::Fetch::OpenLibraryFetcher;
 
 OpenLibraryFetcher::OpenLibraryFetcher(QObject* parent_)
-    : Fetcher(parent_), m_started(false) {
+    : Fetcher(parent_), m_imageSize(MediumImage), m_started(false) {
 }
 
 OpenLibraryFetcher::~OpenLibraryFetcher() {
@@ -76,7 +77,11 @@ bool OpenLibraryFetcher::canFetch(int type) const {
       type == Data::Collection::ComicBook;
 }
 
-void OpenLibraryFetcher::readConfigHook(const KConfigGroup&) {
+void OpenLibraryFetcher::readConfigHook(const KConfigGroup& config_) {
+  const int imageSize = config_.readEntry("Image Size", -1);
+  if(imageSize > -1) {
+    m_imageSize = static_cast<ImageSize>(imageSize);
+  }
 }
 
 void OpenLibraryFetcher::search() {
@@ -186,79 +191,89 @@ Tellico::Data::EntryPtr OpenLibraryFetcher::fetchEntryHook(uint uid_) {
     return Data::EntryPtr();
   }
 
-  // possible that the author is set on the work but not the edition
+  // there are several fields which may be set on the work instead of the edition
+  // if any are empty, fetch the work details and update
+
+  // https://bugs.kde.org/show_bug.cgi?id=509124
+  const QString plotString(QStringLiteral("plot"));
   // see https://github.com/internetarchive/openlibrary/issues/8144
-  const QString authorString(QStringLiteral("author"));
-  const QString workString(QStringLiteral("openlibrary-work"));
-  if(entry->field(authorString).isEmpty()) {
-    const QString work = entry->field(workString);
-    if(!work.isEmpty()) {
-      const QUrl workUrl(QStringLiteral("https://openlibrary.org%1.json").arg(work));
-      QStringList authors;
-      const auto output = FileHandler::readDataFile(workUrl, true /*quiet*/);
+  const QString authorString = entry->collection()->type() == Data::Collection::ComicBook
+                               ? QStringLiteral("writer")
+                               : QStringLiteral("author");
+  const QString seriesString(QStringLiteral("series"));
+  if(entry->field(plotString).isEmpty() ||
+     entry->field(authorString).isEmpty() ||
+     entry->field(seriesString).isEmpty()) {
+    const QString work = m_workLink.value(uid_);
+    const QUrl workUrl(QStringLiteral("https://openlibrary.org%1.json").arg(work));
+    const auto output = FileHandler::readDataFile(workUrl, true /*quiet*/);
 #if 0
-      myWarning() << "Remove debug from openlibraryfetcher.cpp";
-      QFile f(QString::fromLatin1("/tmp/openlibrary-work.json"));
-      if(f.open(QIODevice::WriteOnly)) {
-        QTextStream t(&f);
-        t << output;
-      }
-      f.close();
+    myWarning() << "Remove debug openlibrary-work from openlibraryfetcher.cpp";
+    QFile f(QString::fromLatin1("/tmp/openlibrary-work.json"));
+    if(f.open(QIODevice::WriteOnly)) {
+      QTextStream t(&f);
+      t << output;
+    }
+    f.close();
 #endif
-      QJsonDocument doc = QJsonDocument::fromJson(output);
-      const auto obj = doc.object();
-      const auto array = obj.value(QLatin1String("authors")).toArray();
-      for(int i = 0; i < array.count(); i++) {
-        const auto key = array.at(i).toObject().value(authorString)
-                                    .toObject().value(QLatin1String("key")).toString();
-        if(m_authorHash.contains(key)) {
-          authors += m_authorHash.value(key);
-          continue;
-        }
-        // now grab author name by key
-        const QUrl authorUrl(QStringLiteral("https://openlibrary.org%1.json").arg(key));
-        const auto output2 = FileHandler::readDataFile(authorUrl, true /*quiet*/);
-        QJsonDocument doc2 = QJsonDocument::fromJson(output2);
-        const auto s = doc2.object().value(QLatin1String("name")).toString();
-        if(!s.isEmpty()) {
-          m_authorHash.insert(key, s);
-          authors += s;
-        }
+    QJsonDocument doc = QJsonDocument::fromJson(output);
+    const auto obj = doc.object();
+
+    if(entry->field(plotString).isEmpty()) {
+      const auto map = obj.toVariantMap();
+      QString desc = mapValue(map, "description", "value");
+      if(desc.isEmpty()) {
+        desc = mapValue(map, "description");
       }
+      desc.replace(QLatin1Char('\n'), QLatin1String("<br/>"));
+      entry->setField(plotString, desc);
+    }
+
+    if(entry->field(authorString).isEmpty()) {
+      QStringList authors = getAuthorNames(obj[QLatin1String("authors")].toArray().toVariantList());
       if(!authors.isEmpty()) {
         entry->setField(authorString, authors.join(FieldFormat::delimiterString()));
       }
+    }
 
-      // since we already might have the info, check for series in the subjects field
-      const QString seriesStr(QStringLiteral("series"));
-      if(entry->field(seriesStr).isEmpty()) {
-        const auto subjArray = obj.value(QLatin1String("subjects")).toArray();
-        for(const auto& res : subjArray) {
-          QString value = res.toString();
-          if(value.startsWith(QLatin1String("series:"))) {
-            value.remove(0, 7); // remove first 7 characters
-            value.replace(QLatin1Char('_'), QLatin1Char(' '));
-            value = FieldFormat::capitalize(value);
-            entry->setField(seriesStr, value);
-            break;
-          }
+    if(entry->field(seriesString).isEmpty()) {
+      const auto subjArray = obj.value(QLatin1String("subjects")).toArray();
+      for(const auto& res : subjArray) {
+        QString value = res.toString();
+        if(value.startsWith(QLatin1String("series:"))) {
+          value.remove(0, 7); // remove first 7 characters
+          value.replace(QLatin1Char('_'), QLatin1Char(' '));
+          value = FieldFormat::capitalize(value);
+          entry->setField(seriesString, value);
+          break;
         }
       }
     }
   }
-  // no longer need the field
-  entry->collection()->removeField(workString);
 
-  // if the entry is not set, go ahead and try to fetch it
   const QString coverString(QStringLiteral("cover"));
-  if(entry->field(coverString).isEmpty()) {
-    const QString isbn = ISBNValidator::cleanValue(entry->field(QStringLiteral("isbn")));
-    if(!isbn.isEmpty()) {
-      QUrl imageUrl(QStringLiteral("https://covers.openlibrary.org/b/isbn/%1-M.jpg?default=false").arg(isbn));
-      const QString id = ImageFactory::addImage(imageUrl, true);
-      if(!id.isEmpty()) {
-        entry->setField(coverString, id);
-      }
+  if(m_imageSize != NoImage && entry->field(coverString).isEmpty()) {
+    QString imgSize;
+    switch(m_imageSize) {
+      case LargeImage:  imgSize = QLatin1Char('L'); break;
+      case MediumImage: imgSize = QLatin1Char('M'); break;
+      case SmallImage:  imgSize = QLatin1Char('S'); break;
+      case NoImage: break;
+    }
+    QString coverId, imageUrl;
+
+    // just want the portion after the last slash
+    const QString olid = m_olidLink.value(uid_).section(QLatin1Char('/'), -1);
+    if(!olid.isEmpty()) {
+      coverId = olid;
+      imageUrl = QStringLiteral("https://covers.openlibrary.org/b/olid/%1-%2.jpg?default=false");
+    } else {
+      coverId = ISBNValidator::cleanValue(entry->field(QStringLiteral("isbn")));
+      imageUrl = QStringLiteral("https://covers.openlibrary.org/b/isbn/%1-%2.jpg?default=false");
+    }
+    if(!coverId.isEmpty()) {
+      imageUrl = imageUrl.arg(coverId, imgSize);
+      entry->setField(coverString, ImageFactory::addImage(QUrl(imageUrl), true));
     }
   }
 
@@ -266,6 +281,10 @@ Tellico::Data::EntryPtr OpenLibraryFetcher::fetchEntryHook(uint uid_) {
 }
 
 Tellico::Fetch::FetchRequest OpenLibraryFetcher::updateRequest(Data::EntryPtr entry_) {
+  QString olid = entry_->field(QStringLiteral("openlibrary")).section(QLatin1Char('/'), -2);
+  if(!olid.isEmpty()) {
+    return FetchRequest(Raw, QStringLiteral("key=/") + olid);
+  }
   const QString isbn = entry_->field(QStringLiteral("isbn"));
   if(!isbn.isEmpty()) {
     return FetchRequest(ISBN, isbn);
@@ -304,16 +323,15 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
     return;
   }
 
-  QByteArray data = job->data();
+  const QByteArray data = job->data();
   if(data.isEmpty()) {
-    myDebug() << "no data";
     endJob(job);
     return;
   }
 
 #if 0
   myWarning() << "Remove debug from openlibraryfetcher.cpp";
-  QFile f(QString::fromLatin1("/tmp/test.json"));
+  QFile f(QString::fromLatin1("/tmp/openlibrary-result.json"));
   if(f.open(QIODevice::WriteOnly)) {
     QTextStream t(&f);
     t << data;
@@ -324,7 +342,6 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
   QJsonDocument doc = QJsonDocument::fromJson(data);
   QJsonArray array = doc.array();
   if(array.isEmpty()) {
-//    myDebug() << "no results";
     endJob(job);
     return;
   }
@@ -335,15 +352,6 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
   } else {
     coll = new Data::BookCollection(true);
   }
-  // add a temporary work id field
-  Data::FieldPtr wField(new Data::Field(QStringLiteral("openlibrary-work"), QString()));
-  coll->addField(wField);
-
-  if(!coll->hasField(QStringLiteral("openlibrary")) && optionalFields().contains(QStringLiteral("openlibrary"))) {
-    Data::FieldPtr field(new Data::Field(QStringLiteral("openlibrary"), i18n("OpenLibrary Link"), Data::Field::URL));
-    field->setCategory(i18n("General"));
-    coll->addField(field);
-  }
 
   for(int i = 0; i < array.count(); i++) {
     // be sure to check that the fetcher has not been stopped
@@ -366,7 +374,19 @@ void OpenLibraryFetcher::slotComplete(KJob* job_) {
 
     FetchResult* r = new FetchResult(this, entry);
     m_entries.insert(r->uid, entry);
-    emit signalResultFound(r);
+
+    // retain olid and link to parent work
+    m_olidLink.insert(r->uid, mapValue(resultMap, "key"));
+    const auto works = resultMap[QLatin1String("works")].toList();
+    if(!works.isEmpty()) {
+      const auto workMap = works.first().toMap();
+      const QString key = mapValue(workMap, "key");
+      if(!key.isEmpty()) {
+        m_workLink.insert(r->uid, key);
+      }
+    }
+
+    Q_EMIT signalResultFound(r);
   }
 
 //  m_start = m_entries.count();
@@ -428,43 +448,37 @@ void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_
   entry_->setField(QStringLiteral("publisher"), mapValue(map_, "publishers"));
   entry_->setField(QStringLiteral("series"), mapValue(map_, "series"));
   entry_->setField(QStringLiteral("pages"), mapValue(map_, "number_of_pages"));
-  entry_->setField(QStringLiteral("comments"), mapValue(map_, "notes", "value"));
 
-  if(optionalFields().contains(QStringLiteral("openlibrary"))) {
-    entry_->setField(QStringLiteral("openlibrary"), QLatin1String("https://openlibrary.org") + mapValue(map_, "key"));
+  QString desc = mapValue(map_, "description", "value");
+  if(desc.isEmpty()) {
+    desc = mapValue(map_, "description");
   }
-  const auto works = map_.value(QLatin1String("works")).toList();
-  if(!works.isEmpty()) {
-    const auto w = works.front().toMap().value(QLatin1String("key")).toString();
-    if(!w.isEmpty()) entry_->setField(QStringLiteral("openlibrary-work"), w);
+  desc.replace(QLatin1Char('\n'), QLatin1String("<br/>"));
+  entry_->setField(QStringLiteral("plot"), desc);
+
+  QString notes = mapValue(map_, "notes", "value");
+  if(notes.isEmpty()) {
+    notes = mapValue(map_, "notes");
   }
+  notes.replace(QLatin1Char('\n'), QLatin1String("<br/>"));
+  entry_->setField(QStringLiteral("comments"), notes);
 
-  QStringList authors;
-  foreach(const QVariant& authorMap, map_.value(QLatin1String("authors")).toList()) {
-    const QString key = mapValue(authorMap.toMap(), "key");
-    if(m_authorHash.contains(key)) {
-      authors += m_authorHash.value(key);
-    } else if(!key.isEmpty()) {
-      QUrl authorUrl(QString::fromLatin1(OPENLIBRARY_QUERY_URL));
-      QUrlQuery q;
-      q.addQueryItem(QStringLiteral("type"), QStringLiteral("/type/author"));
-      q.addQueryItem(QStringLiteral("key"), key);
-      q.addQueryItem(QStringLiteral("name"), QString());
-      authorUrl.setQuery(q);
-
-      QString output = FileHandler::readTextFile(authorUrl, true /*quiet*/);
-      QJsonDocument doc = QJsonDocument::fromJson(output.toUtf8());
-      QJsonArray array = doc.array();
-      QVariantMap authorResult = array.isEmpty() ? QVariantMap() : array.at(0).toObject().toVariantMap();
-      const QString name = mapValue(authorResult, "name");
-      if(!name.isEmpty()) {
-        authors << name;
-        m_authorHash.insert(key, name);
-      }
+  const QString openlibraryString(QStringLiteral("openlibrary"));
+  if(optionalFields().contains(openlibraryString)) {
+    if(!entry_->collection()->hasField(openlibraryString)) {
+      Data::FieldPtr field(new Data::Field(openlibraryString, i18n("OpenLibrary Link"), Data::Field::URL));
+      field->setCategory(i18n("General"));
+      entry_->collection()->addField(field);
     }
+    entry_->setField(openlibraryString, QLatin1String("https://openlibrary.org") + mapValue(map_, "key"));
   }
+
+  QStringList authors = getAuthorNames(map_[QLatin1String("authors")].toList());
   if(!authors.isEmpty()) {
-    entry_->setField(QStringLiteral("author"), authors.join(FieldFormat::delimiterString()));
+    const QString authorString = entry_->collection()->type() == Data::Collection::ComicBook
+                                 ? QStringLiteral("writer")
+                                 : QStringLiteral("author");
+    entry_->setField(authorString, authors.join(FieldFormat::delimiterString()));
   }
 
   QStringList translators;
@@ -508,6 +522,64 @@ void OpenLibraryFetcher::populate(Data::EntryPtr entry_, const QVariantMap& map_
   }
 }
 
+QStringList OpenLibraryFetcher::getAuthorNames(const QVariantList& keys_) {
+  QStringList authors;
+  if(keys_.isEmpty()) {
+    return authors;
+  }
+
+  bool emptyQuery = true;
+  QString authorQuery(QLatin1String("key:("));
+  for(int i = 0; i < keys_.count(); i++) {
+    const auto map = keys_.at(i).toMap();
+    QString key = mapValue(map, "author", "key");
+    if(key.isEmpty()) key = mapValue(map, "key");
+    if(key.isEmpty()) {
+      myDebug() << "Failed to pull key from" << map;
+      continue;
+    }
+    if(!key.startsWith(QLatin1String("/authors/"))) {
+      key = QLatin1String("/authors/") + key;
+    }
+    if(m_authorHash.contains(key)) {
+      authors += m_authorHash.value(key);
+      continue;
+    }
+    authorQuery += key + QLatin1String(" OR ");
+    emptyQuery = false;
+  }
+  if(emptyQuery) {
+    // no need to search further
+    return authors;
+  }
+  // remove final OR and add )
+  authorQuery.chop(4); // " OR "
+  authorQuery += QLatin1Char(')');
+
+  QUrlQuery q;
+  q.addQueryItem(QStringLiteral("q"), authorQuery);
+  q.addQueryItem(QStringLiteral("fields"), QStringLiteral("key,name"));
+  QUrl u(QString::fromLatin1(OPENLIBRARY_AUTHOR_QUERY_URL));
+  u.setQuery(q);
+
+  const auto output = FileHandler::readDataFile(u, true /*quiet*/);
+  const QJsonDocument doc = QJsonDocument::fromJson(output);
+  const auto array = doc.object().value(QLatin1String("docs")).toArray();
+  for(int i = 0; i < array.count(); i++) {
+    const auto map = array.at(i).toObject().toVariantMap();
+    QString key = mapValue(map, "key");
+    if(!key.startsWith(QLatin1String("/authors/"))) {
+      key = QLatin1String("/authors/") + key;
+    }
+    const QString author = mapValue(map, "name");
+    if(!author.isEmpty()) {
+      m_authorHash.insert(key, author);
+      authors += author;
+    }
+  }
+  return authors;
+}
+
 QString OpenLibraryFetcher::getAuthorKeys(const QString& term_) {
   QUrl u(QString::fromLatin1(OPENLIBRARY_AUTHOR_QUERY_URL));
   QUrlQuery q;
@@ -516,7 +588,7 @@ QString OpenLibraryFetcher::getAuthorKeys(const QString& term_) {
   u.setQuery(q);
 
 //  myLog() << "Searching for authors:" << u.toDisplayString();
-  QString output = FileHandler::readTextFile(u, true /*quiet*/, true /*utf8*/);
+  const auto output = FileHandler::readDataFile(u, true /*quiet*/);
 #if 0
   myWarning() << "Remove author debug from openlibraryfetcher.cpp";
   QFile f(QString::fromLatin1("/tmp/test-openlibraryauthor.json"));
@@ -526,7 +598,7 @@ QString OpenLibraryFetcher::getAuthorKeys(const QString& term_) {
   }
   f.close();
 #endif
-  const QJsonDocument doc = QJsonDocument::fromJson(output.toUtf8());
+  const QJsonDocument doc = QJsonDocument::fromJson(output);
   const auto array = doc.object().value(QLatin1String("docs")).toArray();
   if(array.isEmpty()) {
     return QString();
@@ -559,15 +631,42 @@ Tellico::StringHash OpenLibraryFetcher::allOptionalFields() {
 
 OpenLibraryFetcher::ConfigWidget::ConfigWidget(QWidget* parent_, const OpenLibraryFetcher* fetcher_)
     : Fetch::ConfigWidget(parent_) {
-  QVBoxLayout* l = new QVBoxLayout(optionsWidget());
-  l->addWidget(new QLabel(i18n("This source has no options."), optionsWidget()));
-  l->addStretch();
+  QGridLayout* l = new QGridLayout(optionsWidget());
+  l->setSpacing(4);
+  l->setColumnStretch(1, 10);
+
+  int row = -1;
+  auto label = new QLabel(i18n("&Image size: "), optionsWidget());
+  l->addWidget(label, ++row, 0);
+  m_imageCombo = new GUI::ComboBox(optionsWidget());
+  m_imageCombo->addItem(i18n("Small Image"), SmallImage);
+  m_imageCombo->addItem(i18n("Medium Image"), MediumImage);
+  m_imageCombo->addItem(i18n("Large Image"), LargeImage);
+  m_imageCombo->addItem(i18n("No Image"), NoImage);
+  void (GUI::ComboBox::* activatedInt)(int) = &GUI::ComboBox::activated;
+  connect(m_imageCombo, activatedInt, this, &ConfigWidget::slotSetModified);
+  l->addWidget(m_imageCombo, row, 1);
+  QString w = i18n("The cover image may be downloaded as well. However, too many large images in the "
+                   "collection may degrade performance.");
+  label->setWhatsThis(w);
+  m_imageCombo->setWhatsThis(w);
+  label->setBuddy(m_imageCombo);
+
+  l->setRowStretch(++row, 10);
+
+  if(fetcher_) {
+    m_imageCombo->setCurrentData(fetcher_->m_imageSize);
+  } else { // defaults
+    m_imageCombo->setCurrentData(MediumImage);
+  }
 
   // now add additional fields widget
   addFieldsWidget(OpenLibraryFetcher::allOptionalFields(), fetcher_ ? fetcher_->optionalFields() : QStringList());
 }
 
-void OpenLibraryFetcher::ConfigWidget::saveConfigHook(KConfigGroup&) {
+void OpenLibraryFetcher::ConfigWidget::saveConfigHook(KConfigGroup& config_) {
+  const int n = m_imageCombo->currentData().toInt();
+  config_.writeEntry("Image Size", n);
 }
 
 QString OpenLibraryFetcher::ConfigWidget::preferredName() const {
