@@ -37,12 +37,17 @@ Q_OBJECT
 public:
   CollectionTypeCombo(QWidget* parent);
   void reset();
+
   void setCurrentType(int type);
   int currentType() const { return currentData().toInt(); }
-  int itemType(int index) const { return itemData(index).toInt(); }
+
+  void setIncludedTypes(const QList<int>& types);
+
   // this method "hides" the normal addItem from QComboBox
   void addItem(const QString& value, int collType);
-  void insertItem(int index, const QString& value, int collType);
+
+private:
+  QList<int> m_includedTypes;
 };
 
   }
