@@ -37,6 +37,9 @@ ParaFieldWidget::ParaFieldWidget(Tellico::Data::FieldPtr field_, QWidget* parent
   if(field_->property(QStringLiteral("spellcheck")) != QLatin1String("false")) {
     m_textEdit->setCheckSpellingEnabled(true);
   }
+  // the default is to replace line feeds with HTML tags
+  m_replaceLineFeeds = field_->property(QStringLiteral("replace-line-feeds")) != QLatin1String("false");
+
   void (KTextEdit::* textChanged)() = &KTextEdit::textChanged;
   connect(m_textEdit, textChanged, this, &ParaFieldWidget::checkModified);
 
@@ -54,13 +57,17 @@ ParaFieldWidget::~ParaFieldWidget() {
 
 QString ParaFieldWidget::text() const {
   QString text = m_textEdit->toPlainText();
-  text.replace(QLatin1Char('\n'), QLatin1String("<br/>"));
+  if(m_replaceLineFeeds) {
+    text.replace(QLatin1Char('\n'), QLatin1String("<br/>"));
+  }
   return text;
 }
 
 void ParaFieldWidget::setTextImpl(const QString& text_) {
   QString s = text_;
-  s.replace(m_brRx, QStringLiteral("\n"));
+  if(m_replaceLineFeeds) {
+    s.replace(m_brRx, QStringLiteral("\n"));
+  }
   m_textEdit->setPlainText(s);
 }
 
@@ -72,3 +79,8 @@ void ParaFieldWidget::clearImpl() {
 QWidget* ParaFieldWidget::widget() {
   return m_textEdit;
 }
+
+void ParaFieldWidget::updateFieldHook(Tellico::Data::FieldPtr, Tellico::Data::FieldPtr newField_) {
+  m_textEdit->setCheckSpellingEnabled(newField_->property(QStringLiteral("spellcheck")) != QLatin1String("false"));
+  m_replaceLineFeeds = newField_->property(QStringLiteral("replace-line-feeds")) != QLatin1String("false");
+}
