@@ -24,12 +24,21 @@
 
 #include "tabwidget.h"
 
+#include <KStandardAction>
+
 #include <QTabBar>
 
 using Tellico::GUI::TabWidget;
 
 TabWidget::TabWidget(QWidget* parent_)
     : QTabWidget(parent_) {
+  auto action = KStandardAction::next(this, &TabWidget::slotNextTab, this);
+  action->setShortcuts(KStandardShortcut::tabNext());
+  addAction(action);
+
+  action = KStandardAction::prior(this, &TabWidget::slotPrevTab, this);
+  action->setShortcuts(KStandardShortcut::tabPrev());
+  addAction(action);
 }
 
 void TabWidget::setFocusToFirstChild() {
@@ -49,3 +58,13 @@ void TabWidget::setTabBarHidden(bool hide_) {
   Q_ASSERT(tabBar);
   tabBar->setHidden(hide_);
 }
+
+void TabWidget::slotNextTab() {
+  const auto next = currentIndex() + 1;
+  setCurrentIndex(next >= count() ? 0 : next);
+}
+
+void TabWidget::slotPrevTab() {
+  const auto prev = currentIndex() - 1;
+  setCurrentIndex(prev < 0 ? count() - 1 : prev);
+}
