@@ -44,11 +44,16 @@ using Tellico::ImageDirectory;
 using Tellico::TemporaryImageDirectory;
 using Tellico::ImageZipArchive;
 
-ImageDirectory::ImageDirectory() : ImageStorage(), m_pathExists(false), m_isLocal(true), m_tempDir(nullptr) {
+ImageDirectory::ImageDirectory() : ImageStorage() {
+  reset();
 }
 
 ImageDirectory::ImageDirectory(const QUrl& dir_) : ImageStorage(), m_tempDir(nullptr) {
-  setDirectory(dir_);
+  if(dir_.isEmpty()) {
+    reset();
+  } else {
+    setDirectory(dir_);
+  }
 }
 
 ImageDirectory::~ImageDirectory() {
@@ -69,8 +74,18 @@ void ImageDirectory::setDirectory(const QUrl& dir_) {
   }
 }
 
+void ImageDirectory::reset() {
+  m_dir.clear();
+  m_pathExists = false;
+  m_isLocal = true;
+  m_imageExists.clear();
+  delete m_tempDir;
+  m_tempDir = nullptr;
+}
+
 bool ImageDirectory::hasImage(const QString& id_) {
   // dir() is virtual
+  if(dir().isEmpty()) return false;
   const bool localExists = m_pathExists && m_isLocal && QFile::exists(dir().toLocalFile() + id_);
   if(localExists) return true;
 
