@@ -81,7 +81,7 @@ void ImageFactory::init() {
   factory = new ImageFactory();
   const QUrl dataDir = QUrl::fromLocalFile(Tellico::saveLocation(QStringLiteral("data/")));
   factory->d->dataImageDir.setDirectory(dataDir);
-  myLog() << "Setting local image dir:" << factory->d->dataImageDir.dir().url(QUrl::PreferLocalFile);
+  myLog() << "Setting data image dir:" << factory->d->dataImageDir.dir().toDisplayString(QUrl::PreferLocalFile);
 
   myLog() << "Setting max image cache cost:" << Config::imageCacheSize();
   factory->d->imageCache.setMaxCost(Config::imageCacheSize());
@@ -150,7 +150,7 @@ const Tellico::Data::Image& ImageFactory::addImageImpl(const QUrl& url_, bool qu
   job->setReferrer(refer_);
 
   if(!job->exec()) {
-    myDebug() << "ImageJob failed to exec:" << job->errorString();
+    myWarning() << job->errorString();
     // ERR_UNKNOWN is used when the returned image is truly null
     // rather than network error or some such
     if(job->error() == KIO::ERR_UNKNOWN) {
@@ -161,7 +161,7 @@ const Tellico::Data::Image& ImageFactory::addImageImpl(const QUrl& url_, bool qu
 
   const Data::Image& img = job->image();
   if(img.isNull()) {
-    myDebug() << "Null image for" << url_.toDisplayString();
+    myDebug() << "Null image for" << url_.toDisplayString(QUrl::PreferLocalFile | QUrl::NormalizePathSegments);
     return Data::Image::null;
   }
 
@@ -331,7 +331,7 @@ bool ImageFactory::writeCachedImage(const QString& id_, ImageDirectory* imgDir_,
   if(id_.isEmpty() || !imgDir_) {
     return false;
   }
-//  myLog() << "ImageFactory::writeCachedImage() - dir =" << imgDir_->path() << "; id =" << id_;
+//  myLog() << "ImageFactory::writeCachedImage() - dir =" << imgDir_->dir().path() << "; id =" << id_;
   const bool exists = imgDir_->hasImage(id_);
   // only write if it doesn't exist
   bool success = (!force_ && exists);
@@ -487,17 +487,25 @@ const Tellico::Data::Image& ImageFactory::imageById(const QString& id_) {
   return Data::Image::null;
 }
 
-bool ImageFactory::hasLocalImage(const QString& id_) {
+bool ImageFactory::hasImageInDir(const QString& id_) {
   Q_ASSERT(factory && "ImageFactory is not initialized!");
   if(id_.isEmpty() || !factory) {
     return false;
   }
 
-  const bool inConfigLocation = (Config::imageLocation() == Config::ImagesInLocalDir &&
-                                 factory->d->localImageDir.hasImage(id_)) ||
-                                (Config::imageLocation() == Config::ImagesInAppDir &&
-                                 factory->d->dataImageDir.hasImage(id_));
-  return inConfigLocation ||
+  return (Config::imageLocation() == Config::ImagesInLocalDir &&
+          factory->d->localImageDir.hasImage(id_)) ||
+         (Config::imageLocation() == Config::ImagesInAppDir &&
+          factory->d->dataImageDir.hasImage(id_));
+}
+
+bool ImageFactory::hasImageInDirOrMemory(const QString& id_) {
+  Q_ASSERT_X(factory, "ImageFactory::hasImageInDirOrMemory", "ImageFactory is not initialized!");
+  if(id_.isEmpty() || !factory) {
+    return false;
+  }
+
+  return hasImageInDir(id_) ||
          factory->d->imageCache.contains(id_) ||
          factory->d->imageDict.contains(id_) ||
          factory->d->tempImageDir.hasImage(id_) ||
@@ -508,7 +516,7 @@ bool ImageFactory::hasLocalImage(const QString& id_) {
 
 void ImageFactory::requestImageById(const QString& id_) {
   Q_ASSERT(factory && "ImageFactory is not initialized!");
-  if(hasLocalImage(id_)) {
+  if(hasImageInDirOrMemory(id_)) {
     QTimer::singleShot(0, factory, [id_] () {
       auto img = factory->addCachedImageImpl(id_, cacheDir());
       if(!img.isNull()) {
@@ -651,6 +659,7 @@ void ImageFactory::clean(bool purgeTempDirectory_) {
 }
 
 void ImageFactory::createStyleImages(int collectionType_, const Tellico::StyleOptions& opt_) {
+  myLog() << "Creating style images for type:" << collectionType_;
   const QColor& baseColor = opt_.baseColor.isValid()
                           ? opt_.baseColor
                           : Config::templateBaseColor(collectionType_);
@@ -684,13 +693,13 @@ void ImageFactory::createStyleImages(int collectionType_, const Tellico::StyleOp
 }
 
 void ImageFactory::removeImage(const QString& id_, bool deleteImage_) {
-  myLog() << "Removing image from cache:" << id_;
+//  myLog() << "Removing image from cache:" << id_;
   // be careful using this
   delete factory->d->imageDict.take(id_);
   factory->d->imageCache.remove(id_);
 
   if(deleteImage_) {
-    myLog() << "Deleting image:" << id_;
+//    myLog() << "Deleting image:" << id_;
     // remove from everywhere
     factory->d->dataImageDir.removeImage(id_);
     factory->d->localImageDir.removeImage(id_);
@@ -726,7 +735,7 @@ void ImageFactory::releaseImages() {
   }
 
   myLog() << "Releasing" << s_imagesToRelease.count() << "images from internal memory";
-  foreach(const QString& id, s_imagesToRelease) {
+  for(const QString& id : s_imagesToRelease) {
     if(!d->imageDict.contains(id)) {
       continue;
     }
@@ -764,7 +773,8 @@ void ImageFactory::setLocalDirectory(const QUrl& url_) {
   Q_ASSERT(factory && "ImageFactory is not initialized!");
   const auto localDirName = localDirectory(url_);
   if(localDirName.isEmpty()) {
-    myDebug() << "Trying to set an empty local directory";
+    myLog() << "Clearing the local directory name";
+    factory->d->localImageDir.reset();
   } else {
     myLog() << "Setting local directory to" << localDirName.toDisplayString(QUrl::PreferLocalFile);
     factory->d->localImageDir.setDirectory(localDirName);
