@@ -128,7 +128,7 @@ QVariant FilterModel::data(const QModelIndex& index_, int role_) const {
       if(parent.isValid()) {
         // it points to an entry
         Data::EntryPtr e = entry(index_);
-        return e ? e->formattedField(QStringLiteral("title")) : QString();
+        return e ? e->title() : QString();
       } else {
         // it points to a filter
         FilterPtr f = filter(index_);
