@@ -22,6 +22,7 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <config.h>
 #include "printhandler.h"
 #include "document.h"
 #include "controller.h"
@@ -34,6 +35,7 @@
 #include <KHTMLPart>
 #include <KHTMLView>
 #include <KAboutData>
+class QWebEngineView {};
 #else
 #include <QWebEngineView>
 #include <QWebEnginePage>
@@ -43,38 +45,11 @@
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
 #include <QPrintPreviewWidget>
-#include <QEventLoop>
+#include <QPaintEngine>
 #endif
 
 using Tellico::PrintHandler;
 
-#ifndef USE_KHTML
-class WebPagePrintable : public QWebEnginePage {
-Q_OBJECT
-
-public:
-  WebPagePrintable(QWebEngineView* parent) : QWebEnginePage(parent) {
-    QWebEngineSettings* settings = this->settings();
-    settings->setAttribute(QWebEngineSettings::JavascriptEnabled, false);
-    settings->setAttribute(QWebEngineSettings::PluginsEnabled, false);
-    settings->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, true);
-    settings->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, true);
-  }
-
-public Q_SLOTS:
-  void printDocument(QPrinter* printer) {
-    Tellico::GUI::CursorSaver cs(Qt::WaitCursor);
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    QEventLoop loop;
-    print(printer, [&](bool) { loop.quit(); });
-    loop.exec();
-#else
-    static_cast<QWebEngineView*>(parent())->print(printer);
-#endif
-  }
-};
-#endif
-
 PrintHandler::PrintHandler(QObject* parent_) : QObject(parent_)
     , m_inPrintPreview(false) {
 }
@@ -95,14 +70,6 @@ void PrintHandler::setColumns(const QStringList& columns_) {
 void PrintHandler::print() {
   GUI::CursorSaver cs(Qt::WaitCursor);
 
-  if(m_html.isEmpty()) {
-    m_html = generateHtml();
-    if(m_html.isEmpty()) {
-      myDebug() << "PrintHandler - empty html output";
-      return;
-    }
-  }
-
 #ifdef USE_KHTML
   KHTMLPart w;
 
@@ -125,27 +92,21 @@ void PrintHandler::print() {
   w.end();
   w.view()->print();
 #else
-  QScopedPointer<QWebEngineView> view(new QWebEngineView);
-  WebPagePrintable* page = new WebPagePrintable(view.data());
-  view->setPage(page);
-  view->setHtml(m_html, Data::Document::self()->URL());
+
+  if(!printPrepare()) return;
+
+  m_view->setHtml(m_html, Data::Document::self()->URL());
+  m_printer->setDocName(Data::Document::self()->URL().fileName());
 
   // don't have busy cursor when showing the print dialog
   cs.restore();
 
-  auto info = QPrinterInfo::defaultPrinter();
-  QScopedPointer<QPrinter> printer;
-  if(info.isNull()) {
-    printer.reset(new QPrinter);
-  } else {
-    printer.reset(new QPrinter(info));
-  }
-  printer->setResolution(300);
-  QPointer<QPrintDialog> dialog = new QPrintDialog(printer.data(), view.data());
-  if(dialog->exec() != QDialog::Accepted) {
+  QPrintDialog dialog(m_printer.get(), m_view.get());
+  if(dialog.exec() != QDialog::Accepted) {
     return;
   }
-  page->printDocument(printer.data());
+
+  printDocument(dialog.printer());
 #endif
 }
 
@@ -155,48 +116,78 @@ void PrintHandler::printPreview() {
   if(m_inPrintPreview) {
     return;
   }
+  myLog() << "Previewing print job";
   GUI::CursorSaver cs(Qt::WaitCursor);
 
-  if(m_html.isEmpty()) {
-    m_html = generateHtml();
-    if(m_html.isEmpty()) {
-      myDebug() << "PrintHandler - empty html output in preview";
-      return;
-    }
-  }
-
-  QScopedPointer<QWebEngineView> view(new QWebEngineView);
-  WebPagePrintable* page = new WebPagePrintable(view.data());
-  view->setPage(page);
-  view->setHtml(m_html, Data::Document::self()->URL());
-
-  // don't have busy cursor when showing the print dialog
-  cs.restore();
+  if(!printPrepare()) return;
 
   m_inPrintPreview = true;
-  auto info = QPrinterInfo::defaultPrinter();
-  QScopedPointer<QPrinter> printer;
-  if(info.isNull()) {
-    printer.reset(new QPrinter);
-  } else {
-    printer.reset(new QPrinter(info));
-  }
-  printer->setResolution(300);
-  QPrintPreviewDialog preview(printer.data(), view.data());
-  connect(&preview, &QPrintPreviewDialog::paintRequested,
-          page, &WebPagePrintable::printDocument);
+  m_view->setHtml(m_html, Data::Document::self()->URL());
+
+  // don't have busy cursor when showing the dialog
+  cs.restore();
+
+  // do not use m_printer, this one is specific to preview widget
+  QPrinter previewPrinter;
+  QPrintPreviewDialog preview(&previewPrinter, m_view.get());
+  QObject::connect(&preview, &QPrintPreviewDialog::paintRequested,
+                   this, &PrintHandler::printDocument);
   {
-    // this is a workaround for ensuring the initial dailog open shows the preview already
+    // this is a workaround for ensuring the initial dialog open shows the preview already
     // with Qt 5.15.2, it didn't seem to get previewed initially
-    QList<QPrintPreviewWidget*> list = preview.findChildren<QPrintPreviewWidget*>();
-    QPrintPreviewWidget* w = list.first();
-    if(w) w->updatePreview();
+    auto list = preview.findChildren<QPrintPreviewWidget*>();
+    if(!list.isEmpty()) list.first()->updatePreview();
   }
   preview.exec();
   m_inPrintPreview = false;
 #endif
 }
 
+void PrintHandler::printDocument(QPrinter* printer_) {
+  if(printer_->paintEngine()->type() == QPaintEngine::Picture) {
+    myLog() << "Printing preview...";
+  } else if(printer_->outputFormat() == QPrinter::PdfFormat) {
+    myLog() << "Printing PDF to" << printer_->outputFileName();
+  } else {
+    myLog() << "Printing to" << printer_->printerName();
+  }
+
+  if(printer_->outputFormat() == QPrinter::PdfFormat) {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    m_view->page()->printToPdf(printer_->outputFileName(), printer_->pageLayout());
+#else
+    m_view->printToPdf(printer_->outputFileName(), printer_->pageLayout());
+#endif
+  } else {
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    m_view->page()->print(printer_, [=](bool b) { printFinished(b); });
+#else
+    m_view->print(printer_);
+#endif
+  }
+  // User input in the print preview dialog while we're waiting on a print task
+  // can mess up the internal state and cause a crash.
+  m_waitForResult.exec(QEventLoop::ExcludeUserInputEvents);
+}
+
+void PrintHandler::printFinished(bool success_) {
+  if(success_) {
+    myLog() << "Printing completed";
+  } else {
+    myLog() << "Printing failed";
+  }
+  m_waitForResult.quit();
+}
+
+void PrintHandler::pdfPrintFinished(const QString&, bool success_) {
+  if(success_) {
+    myLog() << "PDF printing completed";
+  } else {
+    myLog() << "PDF printing failed";
+  }
+  m_waitForResult.quit();
+}
+
 QString PrintHandler::generateHtml() const {
   Export::HTMLExporter exporter(Data::Document::self()->collection());
   // only print visible entries
@@ -219,6 +210,42 @@ QString PrintHandler::generateHtml() const {
   return exporter.text();
 }
 
+bool PrintHandler::printPrepare() {
+  if(m_html.isEmpty()) {
+    m_html = generateHtml();
+    if(m_html.isEmpty()) {
+      myDebug() << "PrintHandler - empty html output";
+      return false;
+    }
+  }
+
 #ifndef USE_KHTML
-#include "printhandler.moc"
+  if(!m_view) {
+    m_view.reset(new QWebEngineView);
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    // no printFinished signal in Qt5, so there's a callback specified directly in the print() call
+    connect(m_view->page(), &QWebEnginePage::pdfPrintingFinished, this, &PrintHandler::pdfPrintFinished);
+#else
+    connect(m_view.get(), &QWebEngineView::printFinished, this, &PrintHandler::printFinished);
+    connect(m_view.get(), &QWebEngineView::pdfPrintingFinished, this, &PrintHandler::pdfPrintFinished);
 #endif
+
+    auto settings = m_view->settings();
+    settings->setAttribute(QWebEngineSettings::JavascriptEnabled, false);
+    settings->setAttribute(QWebEngineSettings::PluginsEnabled, false);
+    settings->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, true);
+    settings->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, true);
+  }
+
+  if(!m_printer) {
+    auto info = QPrinterInfo::defaultPrinter();
+    if(info.isNull()) {
+      m_printer.reset(new QPrinter(QPrinter::HighResolution));
+    } else {
+      m_printer.reset(new QPrinter(info, QPrinter::HighResolution));
+    }
+    m_printer->setCreator(QStringLiteral("Tellico/%1").arg(QStringLiteral(TELLICO_VERSION)));
+  }
+#endif
+  return true;
+}
