@@ -34,7 +34,7 @@ QTEST_APPLESS_MAIN( CueCatTest )
 
 Q_DECLARE_METATYPE(QValidator::State)
 
-#define QL1(x) QString::fromLatin1(x)
+#define QL1(x) QStringLiteral(x)
 
 void CueCatTest::initTestCase() {
   qRegisterMetaType<QValidator::State>();
