@@ -52,6 +52,7 @@ void GCstarTest::initTestCase() {
   gcstarImageDir.removeRecursively();
   Tellico::ImageFactory::init();
   Tellico::DataFileRegistry::self()->addDataLocation(QFINDTESTDATA("../../xslt/gcstar2tellico.xsl"));
+  Tellico::DataFileRegistry::self()->addDataLocation(QFINDTESTDATA("data/Knives.gcm")); // for custom collection
   // need to register the collection types
   Tellico::CollectionInitializer ci;
 }
@@ -81,6 +82,9 @@ void GCstarTest::testBook() {
   QCOMPARE(FIELDS(entry, "keyword").count(), 2);
   QCOMPARE(FIELDS(entry, "keyword").at(0), QStringLiteral("tag1"));
   QCOMPARE(FIELDS(entry, "keyword").at(1), QStringLiteral("tag2"));
+  QCOMPARE(entry->field("pur_date"), QStringLiteral("2013-09-02"));
+  QCOMPARE(entry->field("cdate"), QStringLiteral("2013-10-02"));
+  QCOMPARE(entry->field("mdate"), QStringLiteral("2013-10-02"));
   // file has rating of 4, Tellico uses half the rating of GCstar, so it should be 2
   QCOMPARE(entry->field("rating"), QStringLiteral("2"));
   QCOMPARE(FIELDS(entry, "language").count(), 1);
@@ -91,7 +95,6 @@ void GCstarTest::testBook() {
 
   Tellico::Import::GCstarImporter importer2(exporter.text());
   Tellico::Data::CollPtr coll2 = importer2.collection();
-
   QVERIFY(coll2);
   QCOMPARE(coll2->type(), coll->type());
   QCOMPARE(coll2->entryCount(), coll->entryCount());
@@ -136,7 +139,7 @@ void GCstarTest::testComicBook() {
   QCOMPARE(entry->field("category"), QStringLiteral("category"));
   QCOMPARE(entry->field("format"), QStringLiteral("format"));
   QCOMPARE(entry->field("collection"), QStringLiteral("collection"));
-  QCOMPARE(entry->field("pur_date"), QStringLiteral("29/08/2010"));
+  QCOMPARE(entry->field("cdate"), QStringLiteral("2010-08-29"));
   QCOMPARE(entry->field("pur_price"), QStringLiteral("12.99"));
   QCOMPARE(entry->field("numberboards"), QStringLiteral("1"));
   QCOMPARE(entry->field("signed"), QStringLiteral("true"));
@@ -386,7 +389,6 @@ void GCstarTest::testBoardGame() {
 void GCstarTest::testWine() {
   QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-wine.gcs"));
   Tellico::Import::GCstarImporter importer(url);
-  importer.setHasRelativeImageLinks(true);
   Tellico::Data::CollPtr coll = importer.collection();
 
   QVERIFY(coll);
@@ -403,7 +405,7 @@ void GCstarTest::testWine() {
   QCOMPARE(entry->field("quantity"), QStringLiteral("1"));
   QCOMPARE(FIELDS(entry, "varietal").count(), 2);
   QCOMPARE(FIELDS(entry, "varietal").at(1), QStringLiteral("grape2"));
-  QCOMPARE(entry->field("pur_date"), QStringLiteral("28/08/2010"));
+  QCOMPARE(entry->field("pur_date"), QStringLiteral("2010-08-28"));
   QCOMPARE(entry->field("pur_price"), QStringLiteral("12.99"));
   QCOMPARE(entry->field("appellation"), QStringLiteral("designation"));
   QCOMPARE(entry->field("distinction"), QStringLiteral("distinction"));
@@ -603,8 +605,62 @@ void GCstarTest::testCustomFields() {
     foreach(Tellico::Data::FieldPtr f, coll->fields()) {
       // skip images
       if(f->type() != Tellico::Data::Field::Image) {
-        QCOMPARE(f->name() + e1->field(f), f->name() + e2->field(f));
+        QCOMPARE(f->name() + e2->field(f), f->name() + e1->field(f));
       }
     }
   }
 }
+
+void GCstarTest::testCustomCollection() {
+  QUrl url = QUrl::fromLocalFile(QFINDTESTDATA("data/test-custom.gcs"));
+  Tellico::Import::GCstarImporter importer(url);
+  importer.setImagePathsAsLinks(true);
+  Tellico::Data::CollPtr coll = importer.collection();
+
+  QVERIFY(coll);
+  QCOMPARE(coll->type(), Tellico::Data::Collection::Base);
+  QCOMPARE(coll->entryCount(), 2);
+  QCOMPARE(coll->title(), QStringLiteral("GCstar Import"));
+
+  // test custom fields
+  Tellico::Data::FieldPtr field = coll->fieldByName(QStringLiteral("gcsfield1"));
+  QVERIFY(field);
+  QCOMPARE(field->name(), QStringLiteral("gcsfield1"));
+  QCOMPARE(field->title(), QStringLiteral("Picture Right"));
+  QCOMPARE(field->type(), Tellico::Data::Field::Image);
+
+  field = coll->fieldByName(QStringLiteral("gcsfield16"));
+  QVERIFY(field);
+  QCOMPARE(field->title(), QStringLiteral("Long Description"));
+  QCOMPARE(field->type(), Tellico::Data::Field::Para);
+
+  field = coll->fieldByName(QStringLiteral("gcsfield25"));
+  QVERIFY(field);
+  QCOMPARE(field->title(), QStringLiteral("Location"));
+  QCOMPARE(field->type(), Tellico::Data::Field::Choice);
+  QCOMPARE(field->flags(), Tellico::Data::Field::AllowGrouped);
+  QCOMPARE(field->allowed(), QStringList() << QStringLiteral("EDC")
+                                           << QStringLiteral("Deposito")
+                                           << QStringLiteral("Estante"));
+  QCOMPARE(field->defaultValue(), QStringLiteral("Deposito"));
+
+  field = coll->fieldByName(QStringLiteral("gcsfield14"));
+  QVERIFY(field);
+  QCOMPARE(field->type(), Tellico::Data::Field::Date);
+
+  field = coll->fieldByName(QStringLiteral("gcsfield28"));
+  QVERIFY(field);
+  QCOMPARE(field->type(), Tellico::Data::Field::Number);
+  QCOMPARE(field->property(QStringLiteral("minimum")), QStringLiteral("17"));
+  QCOMPARE(field->property(QStringLiteral("maximum")), QStringLiteral("30"));
+
+  Tellico::Data::EntryPtr entry = coll->entryById(71);
+  QVERIFY(entry);
+  QCOMPARE(entry->field("gcsfield11"), QStringLiteral("Dark Hollow"));
+  QCOMPARE(entry->field("gcsfield14"), QStringLiteral("2025-06-01"));
+  QCOMPARE(entry->field("gcsfield16"), QStringLiteral("DARK HOLLOW CUTLERY D2 STEEL WOOD HANDLE FIXED BLADE KNIFE KNIFE"));
+  // image field, with relative link
+  QUrl imageLink = url;
+  imageLink = imageLink.resolved(QUrl(QStringLiteral("collectorz/image.png")));
+  QCOMPARE(entry->field("gcsfield1"), imageLink.url());
+}
