@@ -25,7 +25,6 @@
 #include "alexandriaimporter.h"
 #include "../collections/bookcollection.h"
 #include "../entry.h"
-#include "../field.h"
 #include "../fieldformat.h"
 #include "../images/imagefactory.h"
 #include "../utils/isbnvalidator.h"
@@ -44,6 +43,9 @@
 
 using Tellico::Import::AlexandriaImporter;
 
+AlexandriaImporter::AlexandriaImporter() : Importer(), m_widget(nullptr), m_library(nullptr), m_cancelled(false) {
+}
+
 bool AlexandriaImporter::canImport(int type) const {
   return type == Data::Collection::Book;
 }
@@ -57,7 +59,7 @@ Tellico::Data::CollPtr AlexandriaImporter::collection() {
     dataDir.setPath(m_libraryPath);
   } else {
     // no widget and no explicit set of the library path means we fail
-    myWarning() << "no widget and no library path";
+    myLog() << "Alexandria importer has no library path";
     return Data::CollPtr();
   }
   // just a sanity check
@@ -95,7 +97,11 @@ Tellico::Data::CollPtr AlexandriaImporter::collection() {
   static const QRegularExpression spaces(QLatin1String("^ +"));
 
   QTextStream ts;
-  ts.setCodec("UTF-8"); // YAML is always utf8?
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+  ts.setCodec("UTF-8");
+#else
+  ts.setEncoding(QStringConverter::Utf8);
+#endif
   uint j = 0;
   for(QStringList::ConstIterator it = files.begin(); !m_cancelled && it != files.end(); ++it, ++j) {
     QFile file(dataDir.absoluteFilePath(*it));
@@ -107,7 +113,6 @@ Tellico::Data::CollPtr AlexandriaImporter::collection() {
 
     bool readNextLine = true;
     ts.setDevice(&file);
-    ts.setCodec("UTF-8"); // YAML is always utf8?
     QString line;
     while(!ts.atEnd()) {
       if(readNextLine) {
