@@ -44,14 +44,14 @@ Q_OBJECT
 public:
   CSVExporter(Data::CollPtr coll);
 
-  virtual bool exec() Q_DECL_OVERRIDE;
-  virtual QString formatString() const Q_DECL_OVERRIDE;
-  virtual QString fileFilter() const Q_DECL_OVERRIDE;
+  virtual bool exec() override;
+  virtual QString formatString() const override;
+  virtual QString fileFilter() const override;
   QString text() const;
 
-  virtual QWidget* widget(QWidget* parent) Q_DECL_OVERRIDE;
-  virtual void readOptions(KSharedConfigPtr config) Q_DECL_OVERRIDE;
-  virtual void saveOptions(KSharedConfigPtr config) Q_DECL_OVERRIDE;
+  virtual QWidget* widget(QWidget* parent) override;
+  virtual void readOptions(KSharedConfigPtr config) override;
+  virtual void saveOptions(KSharedConfigPtr config) override;
 
 private:
   QString& escapeText(QString& text) const;
