@@ -29,6 +29,7 @@
 #include "../datavectors.h"
 
 class QRegularExpression;
+class QCheckBox;
 
 namespace Tellico {
   namespace Import {
@@ -45,15 +46,11 @@ public:
   GCstarImporter(const QUrl& url);
   GCstarImporter(const QString& text);
 
-  /**
-   */
   virtual Data::CollPtr collection() override;
-  /**
-   */
-  virtual QWidget* widget(QWidget*) override { return nullptr; }
   virtual bool canImport(int type) const override;
+  void setImagePathsAsLinks(bool imagePathsAsLinks);
 
-  void setHasRelativeImageLinks(bool b) { m_relativeImageLinks = b; }
+  virtual QWidget* widget(QWidget*) override;
 
 public Q_SLOTS:
   void slotCancel() override;
@@ -62,11 +59,14 @@ private:
   static QString splitJoin(const QRegularExpression& rx, const QString& s);
 
   void readGCfilms(const QString& text);
-  void readGCstar(const QString& text);
+  void readGCstar(const QString& text, const QString& collType);
 
   Data::CollPtr m_coll;
   bool m_cancelled;
-  bool m_relativeImageLinks;
+  bool m_imageLinksOnly;
+
+  QWidget* m_widget;
+  QCheckBox* m_cbImageLink;
 };
 
   } // end namespace
